@@ -18,6 +18,7 @@
 #include "config.h"
 
 #include <math.h>
+#include <gdk/gdk.h>
 
 #define EGL_EGLEXT_PROTOTYPES
 #define GL_GLEXT_PROTOTYPES
@@ -29,7 +30,9 @@
 #include <libdrm/drm_fourcc.h>
 #endif
 
+#ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
+#endif
 #ifdef GDK_WINDOWING_WAYLAND
 #include <gdk/gdkwayland.h>
 #endif
@@ -277,8 +280,8 @@ end:
 
     d->egl.context_ready = TRUE;
 
-    if (spice_display_get_gl_scanout(SPICE_DISPLAY_CHANNEL(d->display)) != NULL) {
-        SPICE_DEBUG("scanout present during egl init, updating widget");
+    if (spice_display_get_gl_scanout(d->display) != NULL) {
+        DISPLAY_DEBUG(display, "scanout present during egl init, updating widget");
         spice_display_widget_gl_scanout(display);
         spice_display_widget_update_monitor_area(display);
     }
@@ -291,6 +294,9 @@ gl_make_current(SpiceDisplay *display, GError **err)
 {
     SpiceDisplayPrivate *d = SPICE_DISPLAY_GET_PRIVATE(display);
 
+    g_return_val_if_fail(d->egl.context_ready, FALSE);
+
+#ifdef GDK_WINDOWING_X11
     if (GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
         EGLBoolean success = eglMakeCurrent(d->egl.display,
                                             d->egl.surface,
@@ -303,11 +309,18 @@ gl_make_current(SpiceDisplay *display, GError **err)
             return FALSE;
         }
     }
+#endif
 #if GTK_CHECK_VERSION(3,16,0)
-    else {
+#ifdef GDK_WINDOWING_X11
+    else
+#endif
+    {
+        /* Ignore GLib's too-new warnings */
+        G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         GtkWidget *area = gtk_stack_get_child_by_name(d->stack, "gl-area");
 
         gtk_gl_area_make_current(GTK_GL_AREA(area));
+        G_GNUC_END_IGNORE_DEPRECATIONS
     }
 #endif
 
@@ -354,7 +367,7 @@ static gboolean spice_widget_init_egl_win(SpiceDisplay *display, GdkWindow *win,
 G_GNUC_INTERNAL
 gboolean spice_egl_realize_display(SpiceDisplay *display, GdkWindow *win, GError **err)
 {
-    SPICE_DEBUG("egl realize");
+    DISPLAY_DEBUG(display, "egl realize");
     if (!spice_widget_init_egl_win(display, win, err))
         return FALSE;
 
@@ -369,7 +382,7 @@ void spice_egl_unrealize_display(SpiceDisplay *display)
 {
     SpiceDisplayPrivate *d = SPICE_DISPLAY_GET_PRIVATE(display);
 
-    SPICE_DEBUG("egl unrealize %p", d->egl.surface);
+    DISPLAY_DEBUG(display, "egl unrealize %p", d->egl.surface);
 
     if (!gl_make_current(display, NULL))
         return;
@@ -399,6 +412,7 @@ void spice_egl_unrealize_display(SpiceDisplay *display)
         d->egl.prog = 0;
     }
 
+#ifdef GDK_WINDOWING_X11
     if (GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
         /* egl.surface && egl.ctx are only created on x11, see
            spice_egl_init() */
@@ -419,6 +433,7 @@ void spice_egl_unrealize_display(SpiceDisplay *display)
         /* do not call eglterminate() since egl may be used by
          * somebody else code */
     }
+#endif
 }
 
 G_GNUC_INTERNAL
@@ -581,8 +596,8 @@ void spice_egl_update_display(SpiceDisplay *display)
         ty = 1 - ty;
         th = -1 * th;
     }
-    SPICE_DEBUG("update %f +%d+%d %dx%d +%f+%f %fx%f", s, x, y, w, h,
-                tx, ty, tw, th);
+    DISPLAY_DEBUG(display, "update %f +%d+%d %dx%d +%f+%f %fx%f", s, x, y, w, h,
+                  tx, ty, tw, th);
     glBindTexture(GL_TEXTURE_2D, d->egl.tex_id);
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
     glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
@@ -616,10 +631,12 @@ void spice_egl_update_display(SpiceDisplay *display)
                              0, 0, 1, 1);
     }
 
+#ifdef GDK_WINDOWING_X11
     if (GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
         /* gtk+ does the swap with gtkglarea */
         eglSwapBuffers(d->egl.display, d->egl.surface);
     }
+#endif
 
     glUseProgram(prog);
 }
@@ -657,11 +674,11 @@ gboolean spice_egl_update_scanout(SpiceDisplay *display,
     attrs[10] = EGL_LINUX_DRM_FOURCC_EXT;
     attrs[11] = format;
     attrs[12] = EGL_NONE;
-    SPICE_DEBUG("fd:%d stride:%u y0:%d %ux%u format:0x%x (%c%c%c%c)",
-                scanout->fd, scanout->stride, scanout->y0top,
-                scanout->width, scanout->height, format,
-                (int)format & 0xff, (int)(format >> 8) & 0xff,
-                (int)(format >> 16) & 0xff, (int)format >> 24);
+    DISPLAY_DEBUG(display, "fd:%d stride:%u y0:%d %ux%u format:0x%x (%c%c%c%c)",
+                  scanout->fd, scanout->stride, scanout->y0top,
+                  scanout->width, scanout->height, format,
+                  (int)format & 0xff, (int)(format >> 8) & 0xff,
+                  (int)(format >> 16) & 0xff, (int)format >> 24);
 
     d->egl.image = eglCreateImageKHR(d->egl.display,
                                        EGL_NO_CONTEXT,
